import * as mongodb from 'mongodb';
import { Backend, TaskStore } from './interface';
export interface MongodbBackendOptions {
    /**
     * MongoDB connection url
     */
    url?: string;
    /**
     * DB name, default : blackfyre
     */
    dbName?: string;
    /**
     * Collection name, default: tasks
     */
    collectionName?: string;
    /**
     * MongoClient connect options, see: https://mongodb.github.io/node-mongodb-native/3.0/api
     */
    mongoClientOptions?: mongodb.MongoClientOptions;
    /**
     * Results expires in, seconds. default: 86400 (1 day)
     */
    resultsExpireIn?: number;
}
export declare class MongodbBackend extends Backend {
    private options;
    private client;
    constructor(options?: MongodbBackendOptions);
    private getCollection();
    updateState(task: TaskStore): Promise<void>;
    setTaskStatePending(task: TaskStore): Promise<void>;
    setTaskStateReceived(task: TaskStore): Promise<void>;
    setTaskStateStarted(task: TaskStore): Promise<void>;
    setTaskStateRetrying(task: TaskStore, err: Error): Promise<void>;
    setTaskStateSucceed(task: TaskStore, result: any): Promise<void>;
    setTaskStateFailed(task: TaskStore, err: Error): Promise<void>;
    getTask(taskID: string): Promise<TaskStore>;
    removeTask(taskID: string): Promise<void>;
    checkHealth(): Promise<any>;
    close(): Promise<any>;
}
