/// <reference types="node" />
import { EventEmitter } from 'events';
import { Task, RetryStrategy } from './common';
import { BackendType } from './backends/interface';
import { MongodbBackendOptions } from './backends/mongodb';
import { BrokerType } from './brokers/interface';
import { AMQPBrokerOptions } from './brokers/amqp';
export interface ProducerOptions {
    /**
     * Test mode, useful for testing, default false
     */
    isTestMode?: boolean;
    /**
     *  Broker type, default: AMQP
     */
    brokerType?: BrokerType;
    /**
     *  Broker options
     */
    brokerOptions?: AMQPBrokerOptions;
    /**
     *  Backend type, default: MongoDB
     */
    backendType?: BackendType;
    /**
     *  Backend options
     */
    backendOptions?: MongodbBackendOptions;
    /**
     * Global max retry for task, will be override by task metadata, default: 0
     */
    globalMaxRetry?: number;
    /**
     * Global init delay for task, will be override by task metadata, default: 100
     */
    globalInitDelayMs?: number;
    /**
     * Global retry strategy for task, will be override by task metadata, default: FIBONACCI
     */
    globalretryStrategy?: RetryStrategy;
}
export declare class Producer extends EventEmitter {
    private options;
    private backend;
    private broker;
    createdTasks: Task[];
    constructor(options?: ProducerOptions);
    createTask(task: Task): Promise<any>;
    close(): Promise<any>;
    checkHealth(): Promise<any>;
}
